@@ -1,4 +1,4 @@
-const char actions_rcs[] = "$Id: actions.c,v 1.95 2016/01/16 12:33:35 fabiankeil Exp $";
+const char actions_rcs[] = "$Id: actions.c,v 1.97 2016/05/03 13:20:37 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/actions.c,v $
@@ -1080,6 +1080,44 @@ int load_action_files(struct client_state *csp)
 }
 
 
+/*********************************************************************
+ *
+ * Function    :  filter_type_to_string
+ *
+ * Description :  Converts a filter type enum into a string.
+ *
+ * Parameters  :
+ *          1  :  filter_type = filter_type as enum
+ *
+ * Returns     :  Pointer to static string.
+ *
+ *********************************************************************/
+static const char *filter_type_to_string(enum filter_type filter_type)
+{
+   switch (filter_type)
+   {
+   case FT_CONTENT_FILTER:
+      return "content filter";
+   case FT_CLIENT_HEADER_FILTER:
+      return "client-header filter";
+   case FT_SERVER_HEADER_FILTER:
+      return "server-header filter";
+   case FT_CLIENT_HEADER_TAGGER:
+      return "client-header tagger";
+   case FT_SERVER_HEADER_TAGGER:
+      return "server-header tagger";
+#ifdef FEATURE_EXTERNAL_FILTERS
+   case FT_EXTERNAL_CONTENT_FILTER:
+      return "external content filter";
+#endif
+   case FT_INVALID_FILTER:
+      return "invalid filter type";
+   }
+
+   return "unknown filter type";
+
+}
+
 /*********************************************************************
  *
  * Function    :  referenced_filters_are_missing
@@ -1106,7 +1144,8 @@ static int referenced_filters_are_missing(const struct client_state *csp,
    {
       if (NULL == get_filter(csp, filtername->str, filter_type))
       {
-         log_error(LOG_LEVEL_ERROR, "Missing filter '%s'", filtername->str);
+         log_error(LOG_LEVEL_ERROR, "Missing %s '%s'",
+            filter_type_to_string(filter_type), filtername->str);
          return 1;
       }
    }
@@ -1212,13 +1251,7 @@ static int load_one_actions_file(struct client_state *csp, int fileid)
       return 1; /* never get here */
    }
 
-   fs->f = last_perm = (struct url_actions *)zalloc(sizeof(*last_perm));
-   if (last_perm == NULL)
-   {
-      log_error(LOG_LEVEL_FATAL, "can't load actions file '%s': out of memory!",
-                csp->config->actions_file[fileid]);
-      return 1; /* never get here */
-   }
+   fs->f = last_perm = zalloc_or_die(sizeof(*last_perm));
 
    if ((fp = fopen(csp->config->actions_file[fileid], "r")) == NULL)
    {
@@ -1362,15 +1395,7 @@ static int load_one_actions_file(struct client_state *csp, int fileid)
                cur_action = NULL;
             }
             cur_action_used = 0;
-            cur_action = (struct action_spec *)zalloc(sizeof(*cur_action));
-            if (cur_action == NULL)
-            {
-               fclose(fp);
-               log_error(LOG_LEVEL_FATAL,
-                  "can't load actions file '%s': out of memory",
-                  csp->config->actions_file[fileid]);
-               return 1; /* never get here */
-            }
+            cur_action = zalloc_or_die(sizeof(*cur_action));
             init_action(cur_action);
 
             /*
@@ -1486,14 +1511,7 @@ static int load_one_actions_file(struct client_state *csp, int fileid)
             return 1; /* never get here */
          }
 
-         if ((new_alias = zalloc(sizeof(*new_alias))) == NULL)
-         {
-            fclose(fp);
-            log_error(LOG_LEVEL_FATAL,
-               "can't load actions file '%s': out of memory!",
-               csp->config->actions_file[fileid]);
-            return 1; /* never get here */
-         }
+         new_alias = zalloc_or_die(sizeof(*new_alias));
 
          /* Eat any the whitespace before the '=' */
          end--;
@@ -1544,14 +1562,7 @@ static int load_one_actions_file(struct client_state *csp, int fileid)
          /* it's an URL pattern */
 
          /* allocate a new node */
-         if ((perm = zalloc(sizeof(*perm))) == NULL)
-         {
-            fclose(fp);
-            log_error(LOG_LEVEL_FATAL,
-               "can't load actions file '%s': out of memory!",
-               csp->config->actions_file[fileid]);
-            return 1; /* never get here */
-         }
+         perm = zalloc_or_die(sizeof(*perm));
 
          perm->action = cur_action;
          cur_action_used = 1;
