@@ -11,17 +11,13 @@
  *
  *********************************************************************/
 
-#define PCRS_H_VERSION "$Id: pcrs.h,v 1.17 2009/05/16 13:27:20 fabiankeil Exp $"
+#define PCRS_H_VERSION "$Id: pcrs.h,v 1.18 2013/11/24 14:23:28 fabiankeil Exp $"
 
 
 #ifndef _PCRE_H
 #include <pcre.h>
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /*
  * Constants:
  */
@@ -137,10 +133,6 @@ extern pcrs_job *pcrs_compile_dynamic_command(char *pcrs_command, const struct p
 #define PCRS_BUFFER_SIZE 4000
 #endif /* ndef PCRS_BUFFER_SIZE */
 
-#ifdef __cplusplus
-} /* extern "C" */
-#endif
-
 #endif /* ndef PCRS_H_INCLUDED */
 
 /*
